==> ismah-3.0.2%2B1.21.5%2Bneoforge-sources.jar: com/github/razorplay01/ismah/client/util/LeashRenderer.java <==
package com.github.razorplay01.ismah.client.util;

import com.github.razorplay01.ismah.common.mixin.PlayerModelAccessor;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.model.geom.ModelPart;
import net.minecraft.client.model.geom.PartPose;
import net.minecraft.client.model.geom.builders.*;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.RenderType;
import net.minecraft.client.renderer.texture.OverlayTexture;
import net.minecraft.resources.ResourceLocation;

public class LeashRenderer {
    private LeashRenderer() {
        // []
    }
    private static final ResourceLocation TEXTURE = /*? >=1.21 {*/ ResourceLocation.parse /*?} else {*/ /*new ResourceLocation *//*?}*/("textures/entity/lead_knot.png");

    private static final ModelPart RIGHT_LEASH = buildModel(
            "leads$right_leash",
            CubeListBuilder.create().texOffs(0, 0).addBox(1.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static final ModelPart RIGHT_LEASH_SLIM = buildModel(
            "leads$right_leash_slim",
            CubeListBuilder.create().texOffs(0, 0).addBox(2.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static final ModelPart LEFT_LEASH = buildModel(
            "leads$left_leash",
            CubeListBuilder.create().texOffs(0, 0).addBox(3.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static final ModelPart LEFT_LEASH_SLIM = buildModel(
            "leads$left_leash",
            CubeListBuilder.create().texOffs(0, 0).addBox(3.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    private static ModelPart buildModel(String name, CubeListBuilder builder) {
        MeshDefinition modelData = new MeshDefinition();
        PartDefinition modelPartData = modelData.getRoot();
        modelPartData.addOrReplaceChild(name, builder, PartPose.offset(-5.0F, 2.0F, 0.0F));
        return LayerDefinition.create(modelData, 32, 32).bakeRoot();
    }

    public static void renderRightArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                           //? if <=1.21.1 {
                                           /*net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                           *//*?} else {*/
                                           net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                           //?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? RIGHT_LEASH_SLIM : RIGHT_LEASH;
        renderArmLeash(matrices, vertices, light, model.rightArm, leash);
    }

    public static void renderLeftArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                          //? if <=1.21.1 {
                                          /*net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                          *//*?} else {*/
                                          net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                          //?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? LEFT_LEASH_SLIM : LEFT_LEASH;
        renderArmLeash(matrices, vertices, light, model.leftArm, leash);
    }

    public static void renderArmLeash(PoseStack matrices, MultiBufferSource vertices, int light, ModelPart arm, ModelPart leash) {
        leash.x = arm.x;
        leash.y = arm.y;
        leash.z = arm.z;
        leash.xRot = arm.xRot;
        leash.yRot = arm.yRot;
        leash.zRot = arm.zRot;
        leash.xScale = arm.xScale;
        leash.yScale = arm.yScale;
        leash.zScale = arm.zScale;

        leash.render(matrices, vertices.getBuffer(RenderType.entitySolid(TEXTURE)), light, OverlayTexture.NO_OVERLAY);
    }
}

==> ismah-3.1.1%2B1.21%2Bneoforge-sources.jar: com/github/razorplay01/ismah/client/util/LeashRenderer.java <==
package com.github.razorplay01.ismah.client.util;

import com.github.razorplay01.ismah.common.mixin.PlayerModelAccessor;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.model.geom.ModelPart;
import net.minecraft.client.model.geom.PartPose;
import net.minecraft.client.model.geom.builders.*;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.RenderType;
import net.minecraft.client.renderer.texture.OverlayTexture;
import net.minecraft.resources.ResourceLocation;

public class LeashRenderer {
    private LeashRenderer() {
        // []
    }
    private static final ResourceLocation TEXTURE = /*? >=1.21 {*/ ResourceLocation.parse /*?} else {*/ /*new ResourceLocation *//*?}*/("textures/entity/lead_knot.png");

    public static final ModelPart RIGHT_LEASH = buildModel(
            "leads$right_leash",
            CubeListBuilder.create().texOffs(0, 0).addBox(1.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static final ModelPart RIGHT_LEASH_SLIM = buildModel(
            "leads$right_leash_slim",
            CubeListBuilder.create().texOffs(0, 0).addBox(2.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static final ModelPart LEFT_LEASH = buildModel(
            "leads$left_leash",
            CubeListBuilder.create().texOffs(0, 0).addBox(3.0F, -3.0F, -3.0F, 6.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static final ModelPart LEFT_LEASH_SLIM = buildModel(
            "leads$left_leash",
            CubeListBuilder.create().texOffs(0, 0).addBox(3.0F, -3.0F, -3.0F, 5.0F, 8.0F, 6.0F, new CubeDeformation(0.0F))
    );

    public static ModelPart buildModel(String name, CubeListBuilder builder) {
        MeshDefinition modelData = new MeshDefinition();
        PartDefinition modelPartData = modelData.getRoot();
        modelPartData.addOrReplaceChild(name, builder, PartPose.offset(-5.0F, 2.0F, 0.0F));
        return LayerDefinition.create(modelData, 32, 32).bakeRoot();
    }

    public static void renderRightArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                           //? if <=1.21.1 {
                                           net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                           /*?} else {*/
                                           /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                           *///?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? RIGHT_LEASH_SLIM : RIGHT_LEASH;
        renderArmLeash(matrices, vertices, light, model.rightArm, leash);
    }

    public static void renderLeftArmLeash(PoseStack matrices, MultiBufferSource vertices, int light,
                                          //? if <=1.21.1 {
                                          net.minecraft.client.model.PlayerModel<net.minecraft.client.player.AbstractClientPlayer> model
                                          /*?} else {*/
                                          /*net.minecraft.client.model.HumanoidModel<net.minecraft.client.renderer.entity.state.HumanoidRenderState> model
                                          *///?}
    ) {
        ModelPart leash = ((PlayerModelAccessor) model).isSlim() ? LEFT_LEASH_SLIM : LEFT_LEASH;
        renderArmLeash(matrices, vertices, light, model.leftArm, leash);
    }

    public static void renderArmLeash(PoseStack matrices, MultiBufferSource vertices, int light, ModelPart arm, ModelPart leash) {
        leash.x = arm.x;
        leash.y = arm.y;
        leash.z = arm.z;
        leash.xRot = arm.xRot;
        leash.yRot = arm.yRot;
        leash.zRot = arm.zRot;
        leash.xScale = arm.xScale;
        leash.yScale = arm.yScale;
        leash.zScale = arm.zScale;

        leash.render(matrices, vertices.getBuffer(RenderType.entitySolid(TEXTURE)), light, OverlayTexture.NO_OVERLAY);
    }
}
